# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/msgbus_pq.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import pqconfig_pb2 as ydb_dot_core_dot_protos_dot_pqconfig__pb2
from ydb.public.api.protos.draft import persqueue_error_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_draft_dot_persqueue__error__codes__pb2
from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fydb/core/protos/msgbus_pq.proto\x12\rNKikimrClient\x1a\x1eydb/core/protos/pqconfig.proto\x1a\x37ydb/public/api/protos/draft/persqueue_error_codes.proto\x1a&library/cpp/actors/protos/actors.proto\"\x8b\x17\n\x1aTPersQueuePartitionRequest\x12\r\n\x05Topic\x18\x01 \x01(\t\x12\x11\n\tPartition\x18\x02 \x01(\x05\x12\x13\n\x0bOwnerCookie\x18\x03 \x01(\t\x12\x11\n\tMessageNo\x18\x0c \x01(\x03\x12\x16\n\x0e\x43mdWriteOffset\x18\r \x01(\x03\x12\x45\n\x08\x43mdWrite\x18\x04 \x03(\x0b\x32\x33.NKikimrClient.TPersQueuePartitionRequest.TCmdWrite\x12Q\n\x0e\x43mdGetMaxSeqNo\x18\x05 \x01(\x0b\x32\x39.NKikimrClient.TPersQueuePartitionRequest.TCmdGetMaxSeqNo\x12U\n\x10\x43mdDeleteSession\x18\x06 \x01(\x0b\x32;.NKikimrClient.TPersQueuePartitionRequest.TCmdDeleteSession\x12U\n\x10\x43mdCreateSession\x18\x07 \x01(\x0b\x32;.NKikimrClient.TPersQueuePartitionRequest.TCmdCreateSession\x12\x43\n\x07\x43mdRead\x18\x08 \x01(\x0b\x32\x32.NKikimrClient.TPersQueuePartitionRequest.TCmdRead\x12Y\n\x12\x43mdSetClientOffset\x18\t \x01(\x0b\x32=.NKikimrClient.TPersQueuePartitionRequest.TCmdSetClientOffset\x12Y\n\x12\x43mdGetClientOffset\x18\n \x01(\x0b\x32=.NKikimrClient.TPersQueuePartitionRequest.TCmdGetClientOffset\x12S\n\x0f\x43mdGetOwnership\x18\x0b \x01(\x0b\x32:.NKikimrClient.TPersQueuePartitionRequest.TCmdGetOwnership\x12S\n\x0f\x43mdReserveBytes\x18\x0e \x01(\x0b\x32:.NKikimrClient.TPersQueuePartitionRequest.TCmdReserveBytes\x12\x63\n\x17\x43mdRegisterMessageGroup\x18\x14 \x01(\x0b\x32\x42.NKikimrClient.TPersQueuePartitionRequest.TCmdRegisterMessageGroup\x12g\n\x19\x43mdDeregisterMessageGroup\x18\x15 \x01(\x0b\x32\x44.NKikimrClient.TPersQueuePartitionRequest.TCmdDeregisterMessageGroup\x12]\n\x14\x43mdSplitMessageGroup\x18\x16 \x01(\x0b\x32?.NKikimrClient.TPersQueuePartitionRequest.TCmdSplitMessageGroup\x12*\n\nPipeClient\x18\x0f \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x0e\n\x06\x43ookie\x18\x10 \x01(\x04\x12\x63\n\x17\x43mdUpdateWriteTimestamp\x18\x11 \x01(\x0b\x32\x42.NKikimrClient.TPersQueuePartitionRequest.TCmdUpdateWriteTimestamp\x12\x1c\n\rIsDirectWrite\x18\x12 \x01(\x08:\x05\x66\x61lse\x12\x14\n\x0cPutUnitsSize\x18\x13 \x01(\x04\x1a\xb2\x02\n\x08TCmdRead\x12\x10\n\x08\x43lientId\x18\x01 \x01(\t\x12\x11\n\tSessionId\x18\x02 \x01(\t\x12\x0e\n\x06Offset\x18\x03 \x01(\x03\x12\x11\n\x06PartNo\x18\x07 \x01(\x05:\x01\x30\x12\r\n\x05\x43ount\x18\x04 \x01(\x05\x12\r\n\x05\x42ytes\x18\x05 \x01(\x05\x12\x11\n\tTimeoutMs\x18\x06 \x01(\x05\x12\x14\n\x0cMaxTimeLagMs\x18\x08 \x01(\x05\x12\x17\n\x0fReadTimestampMs\x18\t \x01(\x04\x12\x1e\n\x0fMirrorerRequest\x18\n \x01(\x08:\x05\x66\x61lse\x12\x10\n\x08\x43lientDC\x18\x0b \x01(\t\x12\x14\n\x0cPartitionKey\x18\x0c \x01(\t\x12\x14\n\x0c\x45xplicitHash\x18\r \x01(\t\x12 \n\x11\x45xternalOperation\x18\x0e \x01(\x08:\x05\x66\x61lse\x1aZ\n\x11TCmdCreateSession\x12\x10\n\x08\x43lientId\x18\x01 \x01(\t\x12\x11\n\tSessionId\x18\x02 \x01(\t\x12\x12\n\nGeneration\x18\x03 \x01(\x04\x12\x0c\n\x04Step\x18\x04 \x01(\x04\x1a\x38\n\x11TCmdDeleteSession\x12\x10\n\x08\x43lientId\x18\x01 \x01(\t\x12\x11\n\tSessionId\x18\x02 \x01(\t\x1aj\n\x13TCmdSetClientOffset\x12\x10\n\x08\x43lientId\x18\x01 \x01(\t\x12\x0e\n\x06Offset\x18\x02 \x01(\x03\x12\x11\n\tSessionId\x18\x04 \x01(\t\x12\x1e\n\x0fMirrorerRequest\x18\n \x01(\x08:\x05\x66\x61lse\x1a\'\n\x13TCmdGetClientOffset\x12\x10\n\x08\x43lientId\x18\x01 \x01(\t\x1a\xdf\x02\n\tTCmdWrite\x12\x10\n\x08SourceId\x18\x01 \x01(\x0c\x12\r\n\x05SeqNo\x18\x02 \x01(\x03\x12\x0c\n\x04\x44\x61ta\x18\x04 \x01(\x0c\x12\x0e\n\x06PartNo\x18\x05 \x01(\x05\x12\x12\n\nTotalParts\x18\x06 \x01(\x05\x12\x11\n\tTotalSize\x18\x07 \x01(\x05\x12\x14\n\x0c\x43reateTimeMS\x18\x08 \x01(\x03\x12#\n\x14\x44isableDeduplication\x18\t \x01(\x08:\x05\x66\x61lse\x12\x13\n\x0bWriteTimeMS\x18\n \x01(\x03\x12\x18\n\x10UncompressedSize\x18\x0c \x01(\x05\x12\x10\n\x08\x43lientDC\x18\x0b \x01(\t\x12\x14\n\x0cPartitionKey\x18\r \x01(\t\x12\x14\n\x0c\x45xplicitHash\x18\x0e \x01(\x0c\x12 \n\x11\x45xternalOperation\x18\x0f \x01(\x08:\x05\x66\x61lse\x12\"\n\x13IgnoreQuotaDeadline\x18\x10 \x01(\x08:\x05\x66\x61lse\x1a/\n\x18TCmdUpdateWriteTimestamp\x12\x13\n\x0bWriteTimeMS\x18\x01 \x01(\x03\x1a#\n\x0fTCmdGetMaxSeqNo\x12\x10\n\x08SourceId\x18\x02 \x03(\x0c\x1a?\n\x10TCmdGetOwnership\x12\x16\n\x05Owner\x18\x01 \x01(\t:\x07\x64\x65\x66\x61ult\x12\x13\n\x05\x46orce\x18\x02 \x01(\x08:\x04true\x1a\x35\n\x10TCmdReserveBytes\x12\x0c\n\x04Size\x18\x01 \x01(\r\x12\x13\n\x0bLastRequest\x18\x02 \x01(\x08\x1a\x8b\x01\n\x18TCmdRegisterMessageGroup\x12\n\n\x02Id\x18\x01 \x01(\x0c\x12\x38\n\x11PartitionKeyRange\x18\x02 \x01(\x0b\x32\x1d.NKikimrPQ.TPartitionKeyRange\x12\x15\n\rStartingSeqNo\x18\x03 \x01(\x03\x12\x12\n\nAfterSplit\x18\x04 \x01(\x08\x1a(\n\x1aTCmdDeregisterMessageGroup\x12\n\n\x02Id\x18\x01 \x01(\x0c\x1a\xd3\x01\n\x15TCmdSplitMessageGroup\x12^\n\x10\x44\x65registerGroups\x18\x01 \x03(\x0b\x32\x44.NKikimrClient.TPersQueuePartitionRequest.TCmdDeregisterMessageGroup\x12Z\n\x0eRegisterGroups\x18\x02 \x03(\x0b\x32\x42.NKikimrClient.TPersQueuePartitionRequest.TCmdRegisterMessageGroup\"\xdb\x0b\n\x15TPersQueueMetaRequest\x12L\n\x0e\x43mdCreateTopic\x18\x01 \x01(\x0b\x32\x34.NKikimrClient.TPersQueueMetaRequest.TCmdCreateTopic\x12L\n\x0e\x43mdChangeTopic\x18\x02 \x01(\x0b\x32\x34.NKikimrClient.TPersQueueMetaRequest.TCmdChangeTopic\x12L\n\x0e\x43mdDeleteTopic\x18\x03 \x01(\x0b\x32\x34.NKikimrClient.TPersQueueMetaRequest.TCmdDeleteTopic\x12V\n\x13\x43mdGetTopicMetadata\x18\x04 \x01(\x0b\x32\x39.NKikimrClient.TPersQueueMetaRequest.TCmdGetTopicMetadata\x12`\n\x18\x43mdGetPartitionLocations\x18\x05 \x01(\x0b\x32>.NKikimrClient.TPersQueueMetaRequest.TCmdGetPartitionLocations\x12\\\n\x16\x43mdGetPartitionOffsets\x18\x06 \x01(\x0b\x32<.NKikimrClient.TPersQueueMetaRequest.TCmdGetPartitionOffsets\x12Z\n\x15\x43mdGetPartitionStatus\x18\x07 \x01(\x0b\x32;.NKikimrClient.TPersQueueMetaRequest.TCmdGetPartitionStatus\x12\\\n\x16\x43mdGetReadSessionsInfo\x18\x08 \x01(\x0b\x32<.NKikimrClient.TPersQueueMetaRequest.TCmdGetReadSessionsInfo\x1a\x86\x01\n\x0fTCmdCreateTopic\x12\r\n\x05Topic\x18\x01 \x01(\t\x12\x15\n\rNumPartitions\x18\x02 \x01(\x05\x12*\n\x06\x43onfig\x18\x03 \x01(\x0b\x32\x1a.NKikimrPQ.TPQTabletConfig\x12!\n\x16NumPartitionsPerTablet\x18\x04 \x01(\x05:\x01\x35\x1a\x63\n\x0fTCmdChangeTopic\x12\r\n\x05Topic\x18\x01 \x01(\t\x12\x15\n\rNumPartitions\x18\x02 \x01(\x05\x12*\n\x06\x43onfig\x18\x03 \x01(\x0b\x32\x1a.NKikimrPQ.TPQTabletConfig\x1a \n\x0fTCmdDeleteTopic\x12\r\n\x05Topic\x18\x01 \x01(\t\x1a%\n\x14TCmdGetTopicMetadata\x12\r\n\x05Topic\x18\x01 \x03(\t\x1a\x31\n\rTTopicRequest\x12\r\n\x05Topic\x18\x01 \x01(\t\x12\x11\n\tPartition\x18\x02 \x03(\x05\x1as\n\x19TCmdGetPartitionLocations\x12H\n\x0cTopicRequest\x18\x01 \x03(\x0b\x32\x32.NKikimrClient.TPersQueueMetaRequest.TTopicRequest\x12\x0c\n\x04Host\x18\x03 \x01(\t\x1au\n\x17TCmdGetPartitionOffsets\x12H\n\x0cTopicRequest\x18\x01 \x03(\x0b\x32\x32.NKikimrClient.TPersQueueMetaRequest.TTopicRequest\x12\x10\n\x08\x43lientId\x18\x02 \x01(\t\x1at\n\x16TCmdGetPartitionStatus\x12H\n\x0cTopicRequest\x18\x01 \x03(\x0b\x32\x32.NKikimrClient.TPersQueueMetaRequest.TTopicRequest\x12\x10\n\x08\x43lientId\x18\x02 \x01(\t\x1a:\n\x17TCmdGetReadSessionsInfo\x12\x10\n\x08\x43lientId\x18\x01 \x01(\t\x12\r\n\x05Topic\x18\x02 \x03(\t\"\xac\x02\n\x16TPersQueueFetchRequest\x12G\n\tPartition\x18\x01 \x03(\x0b\x32\x34.NKikimrClient.TPersQueueFetchRequest.TPartitionInfo\x12\x15\n\rTotalMaxBytes\x18\x02 \x01(\x05\x12\x11\n\x06WaitMs\x18\x03 \x01(\x05:\x01\x30\x12\x10\n\x08\x43lientId\x18\x04 \x01(\t\x12\x1e\n\x0fMirrorerRequest\x18\x05 \x01(\x08:\x05\x66\x61lse\x1am\n\x0eTPartitionInfo\x12\r\n\x05Topic\x18\x01 \x01(\t\x12\x11\n\tPartition\x18\x02 \x01(\x05\x12\x0e\n\x06Offset\x18\x03 \x01(\x03\x12\x10\n\x08MaxBytes\x18\x04 \x01(\x05\x12\x17\n\x0fReadTimestampMs\x18\x05 \x01(\x04\"\x8a\x02\n\x11TPersQueueRequest\x12\x43\n\x10PartitionRequest\x18\x01 \x01(\x0b\x32).NKikimrClient.TPersQueuePartitionRequest\x12\x39\n\x0bMetaRequest\x18\x02 \x01(\x0b\x32$.NKikimrClient.TPersQueueMetaRequest\x12;\n\x0c\x46\x65tchRequest\x18\x03 \x01(\x0b\x32%.NKikimrClient.TPersQueueFetchRequest\x12\x15\n\rSecurityToken\x18\x05 \x01(\t\x12\x0e\n\x06Ticket\x18\x06 \x01(\t\x12\x11\n\tRequestId\x18\x64 \x01(\t\"\xdc\x19\n\x16TPersQueueMetaResponse\x12i\n\x1c\x43mdGetPartitionOffsetsResult\x18\x01 \x01(\x0b\x32\x43.NKikimrClient.TPersQueueMetaResponse.TCmdGetPartitionOffsetsResult\x12\x63\n\x19\x43mdGetTopicMetadataResult\x18\x02 \x01(\x0b\x32@.NKikimrClient.TPersQueueMetaResponse.TCmdGetTopicMetadataResult\x12m\n\x1e\x43mdGetPartitionLocationsResult\x18\x03 \x01(\x0b\x32\x45.NKikimrClient.TPersQueueMetaResponse.TCmdGetPartitionLocationsResult\x12g\n\x1b\x43mdGetPartitionStatusResult\x18\x04 \x01(\x0b\x32\x42.NKikimrClient.TPersQueueMetaResponse.TCmdGetPartitionStatusResult\x12i\n\x1c\x43mdGetReadSessionsInfoResult\x18\x05 \x01(\x0b\x32\x43.NKikimrClient.TPersQueueMetaResponse.TCmdGetReadSessionsInfoResult\x1a\xb3\x02\n\x1dTCmdGetPartitionOffsetsResult\x12\x65\n\x0bTopicResult\x18\x01 \x03(\x0b\x32P.NKikimrClient.TPersQueueMetaResponse.TCmdGetPartitionOffsetsResult.TTopicResult\x1a\xaa\x01\n\x0cTTopicResult\x12\r\n\x05Topic\x18\x01 \x01(\t\x12@\n\x0fPartitionResult\x18\x02 \x03(\x0b\x32\'.NKikimrPQ.TOffsetsResponse.TPartResult\x12\x34\n\tErrorCode\x18\x03 \x01(\x0e\x32!.NPersQueue.NErrorCode.EErrorCode\x12\x13\n\x0b\x45rrorReason\x18\x04 \x01(\t\x1a\xa8\x02\n\x1aTCmdGetTopicMetadataResult\x12^\n\tTopicInfo\x18\x02 \x03(\x0b\x32K.NKikimrClient.TPersQueueMetaResponse.TCmdGetTopicMetadataResult.TTopicInfo\x1a\xa9\x01\n\nTTopicInfo\x12\r\n\x05Topic\x18\x01 \x01(\t\x12\x15\n\rNumPartitions\x18\x02 \x01(\x05\x12*\n\x06\x43onfig\x18\x03 \x01(\x0b\x32\x1a.NKikimrPQ.TPQTabletConfig\x12\x34\n\tErrorCode\x18\x04 \x01(\x0e\x32!.NPersQueue.NErrorCode.EErrorCode\x12\x13\n\x0b\x45rrorReason\x18\x05 \x01(\t\x1a\x8b\x04\n\x1fTCmdGetPartitionLocationsResult\x12g\n\x0bTopicResult\x18\x02 \x03(\x0b\x32R.NKikimrClient.TPersQueueMetaResponse.TCmdGetPartitionLocationsResult.TTopicResult\x1a\xfe\x02\n\x0cTTopicResult\x12\r\n\x05Topic\x18\x01 \x01(\t\x12\x80\x01\n\x11PartitionLocation\x18\x04 \x03(\x0b\x32\x65.NKikimrClient.TPersQueueMetaResponse.TCmdGetPartitionLocationsResult.TTopicResult.TPartitionLocation\x12\x34\n\tErrorCode\x18\x05 \x01(\x0e\x32!.NPersQueue.NErrorCode.EErrorCode\x12\x13\n\x0b\x45rrorReason\x18\x06 \x01(\t\x1a\x90\x01\n\x12TPartitionLocation\x12\x11\n\tPartition\x18\x01 \x01(\x05\x12\x0c\n\x04Host\x18\x02 \x01(\t\x12\x0e\n\x06HostId\x18\x03 \x01(\x05\x12\x34\n\tErrorCode\x18\x06 \x01(\x0e\x32!.NPersQueue.NErrorCode.EErrorCode\x12\x13\n\x0b\x45rrorReason\x18\x07 \x01(\t\x1a\xb0\x02\n\x1cTCmdGetPartitionStatusResult\x12\x64\n\x0bTopicResult\x18\x02 \x03(\x0b\x32O.NKikimrClient.TPersQueueMetaResponse.TCmdGetPartitionStatusResult.TTopicResult\x1a\xa9\x01\n\x0cTTopicResult\x12\r\n\x05Topic\x18\x01 \x01(\t\x12?\n\x0fPartitionResult\x18\x02 \x03(\x0b\x32&.NKikimrPQ.TStatusResponse.TPartResult\x12\x34\n\tErrorCode\x18\x03 \x01(\x0e\x32!.NPersQueue.NErrorCode.EErrorCode\x12\x13\n\x0b\x45rrorReason\x18\x04 \x01(\t\x1a\x8c\n\n\x1dTCmdGetReadSessionsInfoResult\x12\x65\n\x0bTopicResult\x18\x02 \x03(\x0b\x32P.NKikimrClient.TPersQueueMetaResponse.TCmdGetReadSessionsInfoResult.TTopicResult\x12i\n\rSessionResult\x18\x03 \x03(\x0b\x32R.NKikimrClient.TPersQueueMetaResponse.TCmdGetReadSessionsInfoResult.TSessionResult\x1a\xf9\x02\n\x10TPartitionResult\x12\x35\n\tErrorCode\x18\xbc\x05 \x01(\x0e\x32!.NPersQueue.NErrorCode.EErrorCode\x12\x14\n\x0b\x45rrorReason\x18\xbd\x05 \x01(\t\x12\x11\n\tPartition\x18\x01 \x01(\r\x12\x14\n\x0c\x43lientOffset\x18\x02 \x01(\x04\x12\x13\n\x0bStartOffset\x18\x03 \x01(\x04\x12\x11\n\tEndOffset\x18\x04 \x01(\x04\x12\x12\n\nMessageLag\x18\x05 \x01(\x04\x12\x0f\n\x07TimeLag\x18\x07 \x01(\x04\x12\x0f\n\x07Session\x18\x08 \x01(\t\x12\x12\n\nClientNode\x18\t \x01(\t\x12\x11\n\tProxyNode\x18\n \x01(\t\x12\x12\n\nTabletNode\x18\x0b \x01(\t\x12\x11\n\tTimestamp\x18\x0c \x01(\t\x12\x18\n\x10\x43lientReadOffset\x18\r \x01(\x04\x12\x13\n\x0bReadTimeLag\x18\x0e \x01(\x04\x12\x14\n\x0cTabletNodeId\x18\x0f \x01(\r\x1a\xd7\x01\n\x0cTTopicResult\x12\r\n\x05Topic\x18\x01 \x01(\t\x12m\n\x0fPartitionResult\x18\x02 \x03(\x0b\x32T.NKikimrClient.TPersQueueMetaResponse.TCmdGetReadSessionsInfoResult.TPartitionResult\x12\x34\n\tErrorCode\x18\x03 \x01(\x0e\x32!.NPersQueue.NErrorCode.EErrorCode\x12\x13\n\x0b\x45rrorReason\x18\x04 \x01(\t\x1a\xc2\x03\n\x0eTSessionResult\x12\x0f\n\x07Session\x18\x01 \x01(\t\x12\x11\n\tTimestamp\x18\x05 \x01(\x04\x12\x12\n\nClientNode\x18\x06 \x01(\t\x12\x11\n\tProxyNode\x18\x07 \x01(\t\x12\x34\n\tErrorCode\x18\x08 \x01(\x0e\x32!.NPersQueue.NErrorCode.EErrorCode\x12\x13\n\x0b\x45rrorReason\x18\t \x01(\t\x12|\n\x0fPartitionResult\x18\n \x03(\x0b\x32\x63.NKikimrClient.TPersQueueMetaResponse.TCmdGetReadSessionsInfoResult.TSessionResult.TPartitionResult\x1a\x9b\x01\n\x10TPartitionResult\x12\r\n\x05Topic\x18\x01 \x01(\t\x12\x11\n\tPartition\x18\x02 \x01(\x04\x12\x13\n\x0bNextCommits\x18\x10 \x03(\x04\x12\x12\n\nLastReadId\x18\x11 \x01(\x04\x12\x17\n\x0fReadIdCommitted\x18\x12 \x01(\x04\x12\x10\n\x08\x41ssignId\x18\x13 \x01(\x04\x12\x11\n\tTimestamp\x18\x14 \x01(\x04\"\xc9\x04\n\x0eTCmdReadResult\x12\x11\n\tMaxOffset\x18\x02 \x01(\x04\x12\x35\n\x06Result\x18\x03 \x03(\x0b\x32%.NKikimrClient.TCmdReadResult.TResult\x12\x15\n\rBlobsFromDisk\x18\x04 \x01(\r\x12\x16\n\x0e\x42lobsFromCache\x18\x05 \x01(\r\x12\x34\n\tErrorCode\x18\x06 \x01(\x0e\x32!.NPersQueue.NErrorCode.EErrorCode\x12\x13\n\x0b\x45rrorReason\x18\x07 \x01(\t\x12\x17\n\x0f\x42lobsCachedSize\x18\x08 \x01(\x04\x12\x0f\n\x07SizeLag\x18\t \x01(\x04\x12\x16\n\x0eRealReadOffset\x18\n \x01(\x04\x12\x17\n\x0fWaitQuotaTimeMs\x18\x0b \x01(\x04\x12\x1b\n\x13ReadFromTimestampMs\x18\x0c \x01(\x04\x1a\xfa\x01\n\x07TResult\x12\x0e\n\x06Offset\x18\x01 \x01(\x04\x12\x0c\n\x04\x44\x61ta\x18\x02 \x01(\x0c\x12\x10\n\x08SourceId\x18\x03 \x01(\x0c\x12\r\n\x05SeqNo\x18\x04 \x01(\x04\x12\x0e\n\x06PartNo\x18\x05 \x01(\r\x12\x12\n\nTotalParts\x18\x06 \x01(\r\x12\x11\n\tTotalSize\x18\x07 \x01(\r\x12\x18\n\x10WriteTimestampMS\x18\x08 \x01(\x04\x12\x19\n\x11\x43reateTimestampMS\x18\t \x01(\x04\x12\x18\n\x10UncompressedSize\x18\n \x01(\r\x12\x14\n\x0cPartitionKey\x18\x0b \x01(\t\x12\x14\n\x0c\x45xplicitHash\x18\x0c \x01(\x0c\"\xc5\x01\n\x17TPersQueueFetchResponse\x12\x46\n\nPartResult\x18\x01 \x03(\x0b\x32\x32.NKikimrClient.TPersQueueFetchResponse.TPartResult\x1a\x62\n\x0bTPartResult\x12\r\n\x05Topic\x18\x01 \x01(\t\x12\x11\n\tPartition\x18\x02 \x01(\x05\x12\x31\n\nReadResult\x18\x03 \x01(\x0b\x32\x1d.NKikimrClient.TCmdReadResult\"\xe9\t\n\x1bTPersQueuePartitionResponse\x12R\n\x0e\x43mdWriteResult\x18\x01 \x03(\x0b\x32:.NKikimrClient.TPersQueuePartitionResponse.TCmdWriteResult\x12^\n\x14\x43mdGetMaxSeqNoResult\x18\x02 \x01(\x0b\x32@.NKikimrClient.TPersQueuePartitionResponse.TCmdGetMaxSeqNoResult\x12\x34\n\rCmdReadResult\x18\x03 \x01(\x0b\x32\x1d.NKikimrClient.TCmdReadResult\x12\x66\n\x18\x43mdGetClientOffsetResult\x18\x04 \x01(\x0b\x32\x44.NKikimrClient.TPersQueuePartitionResponse.TCmdGetClientOffsetResult\x12`\n\x15\x43mdGetOwnershipResult\x18\x05 \x01(\x0b\x32\x41.NKikimrClient.TPersQueuePartitionResponse.TCmdGetOwnershipResult\x12\x0e\n\x06\x43ookie\x18\x06 \x01(\x04\x1a\x8a\x02\n\x0fTCmdWriteResult\x12\x16\n\x0e\x41lreadyWritten\x18\x01 \x01(\x08\x12\x10\n\x08SourceId\x18\x02 \x01(\x0c\x12\r\n\x05SeqNo\x18\x03 \x01(\x03\x12\x0e\n\x06Offset\x18\x04 \x01(\x03\x12\x0e\n\x06PartNo\x18\x05 \x01(\x05\x12\x18\n\x10WriteTimestampMS\x18\x06 \x01(\x03\x12\x10\n\x08MaxSeqNo\x18\x07 \x01(\x03\x12\x1d\n\x15PartitionQuotedTimeMs\x18\x08 \x01(\r\x12\x19\n\x11TopicQuotedTimeMs\x18\x0b \x01(\r\x12#\n\x1bTotalTimeInPartitionQueueMs\x18\t \x01(\r\x12\x13\n\x0bWriteTimeMs\x18\n \x01(\r\x1a\xa0\x02\n\x15TCmdGetMaxSeqNoResult\x12\x64\n\x0cSourceIdInfo\x18\x02 \x03(\x0b\x32N.NKikimrClient.TPersQueuePartitionResponse.TCmdGetMaxSeqNoResult.TSourceIdInfo\x1a\xa0\x01\n\rTSourceIdInfo\x12\x10\n\x08SourceId\x18\x01 \x01(\x0c\x12\r\n\x05SeqNo\x18\x02 \x01(\x03\x12\x0e\n\x06Offset\x18\x03 \x01(\x03\x12\x18\n\x10WriteTimestampMS\x18\x04 \x01(\x03\x12\x10\n\x08\x45xplicit\x18\x05 \x01(\x08\x12\x32\n\x05State\x18\x06 \x01(\x0e\x32#.NKikimrPQ.TMessageGroupInfo.EState\x1a\xa6\x01\n\x19TCmdGetClientOffsetResult\x12\x0e\n\x06Offset\x18\x02 \x01(\x04\x12\x11\n\tEndOffset\x18\x03 \x01(\x04\x12\x18\n\x10WriteTimestampMS\x18\x05 \x01(\x04\x12\x19\n\x11\x43reateTimestampMS\x18\x06 \x01(\x04\x12\x0f\n\x07SizeLag\x18\x07 \x01(\x04\x12 \n\x18WriteTimestampEstimateMS\x18\x08 \x01(\x04\x1a-\n\x16TCmdGetOwnershipResult\x12\x13\n\x0bOwnerCookie\x18\x01 \x01(\tB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.msgbus_pq_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TPERSQUEUEPARTITIONREQUEST._serialized_start=180
  _TPERSQUEUEPARTITIONREQUEST._serialized_end=3135
  _TPERSQUEUEPARTITIONREQUEST_TCMDREAD._serialized_start=1572
  _TPERSQUEUEPARTITIONREQUEST_TCMDREAD._serialized_end=1878
  _TPERSQUEUEPARTITIONREQUEST_TCMDCREATESESSION._serialized_start=1880
  _TPERSQUEUEPARTITIONREQUEST_TCMDCREATESESSION._serialized_end=1970
  _TPERSQUEUEPARTITIONREQUEST_TCMDDELETESESSION._serialized_start=1972
  _TPERSQUEUEPARTITIONREQUEST_TCMDDELETESESSION._serialized_end=2028
  _TPERSQUEUEPARTITIONREQUEST_TCMDSETCLIENTOFFSET._serialized_start=2030
  _TPERSQUEUEPARTITIONREQUEST_TCMDSETCLIENTOFFSET._serialized_end=2136
  _TPERSQUEUEPARTITIONREQUEST_TCMDGETCLIENTOFFSET._serialized_start=2138
  _TPERSQUEUEPARTITIONREQUEST_TCMDGETCLIENTOFFSET._serialized_end=2177
  _TPERSQUEUEPARTITIONREQUEST_TCMDWRITE._serialized_start=2180
  _TPERSQUEUEPARTITIONREQUEST_TCMDWRITE._serialized_end=2531
  _TPERSQUEUEPARTITIONREQUEST_TCMDUPDATEWRITETIMESTAMP._serialized_start=2533
  _TPERSQUEUEPARTITIONREQUEST_TCMDUPDATEWRITETIMESTAMP._serialized_end=2580
  _TPERSQUEUEPARTITIONREQUEST_TCMDGETMAXSEQNO._serialized_start=2582
  _TPERSQUEUEPARTITIONREQUEST_TCMDGETMAXSEQNO._serialized_end=2617
  _TPERSQUEUEPARTITIONREQUEST_TCMDGETOWNERSHIP._serialized_start=2619
  _TPERSQUEUEPARTITIONREQUEST_TCMDGETOWNERSHIP._serialized_end=2682
  _TPERSQUEUEPARTITIONREQUEST_TCMDRESERVEBYTES._serialized_start=2684
  _TPERSQUEUEPARTITIONREQUEST_TCMDRESERVEBYTES._serialized_end=2737
  _TPERSQUEUEPARTITIONREQUEST_TCMDREGISTERMESSAGEGROUP._serialized_start=2740
  _TPERSQUEUEPARTITIONREQUEST_TCMDREGISTERMESSAGEGROUP._serialized_end=2879
  _TPERSQUEUEPARTITIONREQUEST_TCMDDEREGISTERMESSAGEGROUP._serialized_start=2881
  _TPERSQUEUEPARTITIONREQUEST_TCMDDEREGISTERMESSAGEGROUP._serialized_end=2921
  _TPERSQUEUEPARTITIONREQUEST_TCMDSPLITMESSAGEGROUP._serialized_start=2924
  _TPERSQUEUEPARTITIONREQUEST_TCMDSPLITMESSAGEGROUP._serialized_end=3135
  _TPERSQUEUEMETAREQUEST._serialized_start=3138
  _TPERSQUEUEMETAREQUEST._serialized_end=4637
  _TPERSQUEUEMETAREQUEST_TCMDCREATETOPIC._serialized_start=3864
  _TPERSQUEUEMETAREQUEST_TCMDCREATETOPIC._serialized_end=3998
  _TPERSQUEUEMETAREQUEST_TCMDCHANGETOPIC._serialized_start=4000
  _TPERSQUEUEMETAREQUEST_TCMDCHANGETOPIC._serialized_end=4099
  _TPERSQUEUEMETAREQUEST_TCMDDELETETOPIC._serialized_start=4101
  _TPERSQUEUEMETAREQUEST_TCMDDELETETOPIC._serialized_end=4133
  _TPERSQUEUEMETAREQUEST_TCMDGETTOPICMETADATA._serialized_start=4135
  _TPERSQUEUEMETAREQUEST_TCMDGETTOPICMETADATA._serialized_end=4172
  _TPERSQUEUEMETAREQUEST_TTOPICREQUEST._serialized_start=4174
  _TPERSQUEUEMETAREQUEST_TTOPICREQUEST._serialized_end=4223
  _TPERSQUEUEMETAREQUEST_TCMDGETPARTITIONLOCATIONS._serialized_start=4225
  _TPERSQUEUEMETAREQUEST_TCMDGETPARTITIONLOCATIONS._serialized_end=4340
  _TPERSQUEUEMETAREQUEST_TCMDGETPARTITIONOFFSETS._serialized_start=4342
  _TPERSQUEUEMETAREQUEST_TCMDGETPARTITIONOFFSETS._serialized_end=4459
  _TPERSQUEUEMETAREQUEST_TCMDGETPARTITIONSTATUS._serialized_start=4461
  _TPERSQUEUEMETAREQUEST_TCMDGETPARTITIONSTATUS._serialized_end=4577
  _TPERSQUEUEMETAREQUEST_TCMDGETREADSESSIONSINFO._serialized_start=4579
  _TPERSQUEUEMETAREQUEST_TCMDGETREADSESSIONSINFO._serialized_end=4637
  _TPERSQUEUEFETCHREQUEST._serialized_start=4640
  _TPERSQUEUEFETCHREQUEST._serialized_end=4940
  _TPERSQUEUEFETCHREQUEST_TPARTITIONINFO._serialized_start=4831
  _TPERSQUEUEFETCHREQUEST_TPARTITIONINFO._serialized_end=4940
  _TPERSQUEUEREQUEST._serialized_start=4943
  _TPERSQUEUEREQUEST._serialized_end=5209
  _TPERSQUEUEMETARESPONSE._serialized_start=5212
  _TPERSQUEUEMETARESPONSE._serialized_end=8504
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONOFFSETSRESULT._serialized_start=5770
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONOFFSETSRESULT._serialized_end=6077
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONOFFSETSRESULT_TTOPICRESULT._serialized_start=5907
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONOFFSETSRESULT_TTOPICRESULT._serialized_end=6077
  _TPERSQUEUEMETARESPONSE_TCMDGETTOPICMETADATARESULT._serialized_start=6080
  _TPERSQUEUEMETARESPONSE_TCMDGETTOPICMETADATARESULT._serialized_end=6376
  _TPERSQUEUEMETARESPONSE_TCMDGETTOPICMETADATARESULT_TTOPICINFO._serialized_start=6207
  _TPERSQUEUEMETARESPONSE_TCMDGETTOPICMETADATARESULT_TTOPICINFO._serialized_end=6376
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONLOCATIONSRESULT._serialized_start=6379
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONLOCATIONSRESULT._serialized_end=6902
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONLOCATIONSRESULT_TTOPICRESULT._serialized_start=6520
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONLOCATIONSRESULT_TTOPICRESULT._serialized_end=6902
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONLOCATIONSRESULT_TTOPICRESULT_TPARTITIONLOCATION._serialized_start=6758
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONLOCATIONSRESULT_TTOPICRESULT_TPARTITIONLOCATION._serialized_end=6902
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONSTATUSRESULT._serialized_start=6905
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONSTATUSRESULT._serialized_end=7209
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONSTATUSRESULT_TTOPICRESULT._serialized_start=7040
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONSTATUSRESULT_TTOPICRESULT._serialized_end=7209
  _TPERSQUEUEMETARESPONSE_TCMDGETREADSESSIONSINFORESULT._serialized_start=7212
  _TPERSQUEUEMETARESPONSE_TCMDGETREADSESSIONSINFORESULT._serialized_end=8504
  _TPERSQUEUEMETARESPONSE_TCMDGETREADSESSIONSINFORESULT_TPARTITIONRESULT._serialized_start=7456
  _TPERSQUEUEMETARESPONSE_TCMDGETREADSESSIONSINFORESULT_TPARTITIONRESULT._serialized_end=7833
  _TPERSQUEUEMETARESPONSE_TCMDGETREADSESSIONSINFORESULT_TTOPICRESULT._serialized_start=7836
  _TPERSQUEUEMETARESPONSE_TCMDGETREADSESSIONSINFORESULT_TTOPICRESULT._serialized_end=8051
  _TPERSQUEUEMETARESPONSE_TCMDGETREADSESSIONSINFORESULT_TSESSIONRESULT._serialized_start=8054
  _TPERSQUEUEMETARESPONSE_TCMDGETREADSESSIONSINFORESULT_TSESSIONRESULT._serialized_end=8504
  _TPERSQUEUEMETARESPONSE_TCMDGETREADSESSIONSINFORESULT_TSESSIONRESULT_TPARTITIONRESULT._serialized_start=8349
  _TPERSQUEUEMETARESPONSE_TCMDGETREADSESSIONSINFORESULT_TSESSIONRESULT_TPARTITIONRESULT._serialized_end=8504
  _TCMDREADRESULT._serialized_start=8507
  _TCMDREADRESULT._serialized_end=9092
  _TCMDREADRESULT_TRESULT._serialized_start=8842
  _TCMDREADRESULT_TRESULT._serialized_end=9092
  _TPERSQUEUEFETCHRESPONSE._serialized_start=9095
  _TPERSQUEUEFETCHRESPONSE._serialized_end=9292
  _TPERSQUEUEFETCHRESPONSE_TPARTRESULT._serialized_start=9194
  _TPERSQUEUEFETCHRESPONSE_TPARTRESULT._serialized_end=9292
  _TPERSQUEUEPARTITIONRESPONSE._serialized_start=9295
  _TPERSQUEUEPARTITIONRESPONSE._serialized_end=10552
  _TPERSQUEUEPARTITIONRESPONSE_TCMDWRITERESULT._serialized_start=9779
  _TPERSQUEUEPARTITIONRESPONSE_TCMDWRITERESULT._serialized_end=10045
  _TPERSQUEUEPARTITIONRESPONSE_TCMDGETMAXSEQNORESULT._serialized_start=10048
  _TPERSQUEUEPARTITIONRESPONSE_TCMDGETMAXSEQNORESULT._serialized_end=10336
  _TPERSQUEUEPARTITIONRESPONSE_TCMDGETMAXSEQNORESULT_TSOURCEIDINFO._serialized_start=10176
  _TPERSQUEUEPARTITIONRESPONSE_TCMDGETMAXSEQNORESULT_TSOURCEIDINFO._serialized_end=10336
  _TPERSQUEUEPARTITIONRESPONSE_TCMDGETCLIENTOFFSETRESULT._serialized_start=10339
  _TPERSQUEUEPARTITIONRESPONSE_TCMDGETCLIENTOFFSETRESULT._serialized_end=10505
  _TPERSQUEUEPARTITIONRESPONSE_TCMDGETOWNERSHIPRESULT._serialized_start=10507
  _TPERSQUEUEPARTITIONRESPONSE_TCMDGETOWNERSHIPRESULT._serialized_end=10552
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_kesus.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ydb/core/protos/counters_kesus.proto\x12\x0eNKikimr.NKesus\x1a\x1eydb/core/protos/counters.proto*\x96\x03\n\x0f\x45SimpleCounters\x12\x19\n\x15\x43OUNTER_SIMPLE_IGNORE\x10\x00\x12&\n\x13\x43OUNTER_PROXY_COUNT\x10\x01\x1a\r\x82\xd6\x1b\t\n\x07Proxies\x12)\n\x15\x43OUNTER_SESSION_COUNT\x10\x02\x1a\x0e\x82\xd6\x1b\n\n\x08Sessions\x12\x36\n\x1c\x43OUNTER_SESSION_ACTIVE_COUNT\x10\x03\x1a\x14\x82\xd6\x1b\x10\n\x0e\x41\x63tiveSessions\x12-\n\x17\x43OUNTER_SEMAPHORE_COUNT\x10\x04\x1a\x10\x82\xd6\x1b\x0c\n\nSemaphores\x12\x38\n\x1d\x43OUNTER_SEMAPHORE_OWNER_COUNT\x10\x05\x1a\x15\x82\xd6\x1b\x11\n\x0fSemaphoreOwners\x12:\n\x1e\x43OUNTER_SEMAPHORE_WAITER_COUNT\x10\x06\x1a\x16\x82\xd6\x1b\x12\n\x10SemaphoreWaiters\x12\x38\n\x1d\x43OUNTER_QUOTER_RESOURCE_COUNT\x10\x07\x1a\x15\x82\xd6\x1b\x11\n\x0fQuoterResources*\xb5\n\n\x13\x45\x43umulativeCounters\x12\x1d\n\x19\x43OUNTER_CUMULATIVE_IGNORE\x10\x00\x12K\n!COUNTER_SCHEDULED_SESSION_TIMEOUT\x10\x01\x1a$\x82\xd6\x1b \n\x1e\x45vents/ScheduledSessionTimeout\x12K\n!COUNTER_SCHEDULED_ACQUIRE_TIMEOUT\x10\x02\x1a$\x82\xd6\x1b \n\x1e\x45vents/ScheduledAcquireTimeout\x12\x38\n\x17\x43OUNTER_SESSION_TIMEOUT\x10\x03\x1a\x1b\x82\xd6\x1b\x17\n\x15\x45vents/SessionTimeout\x12\x38\n\x17\x43OUNTER_ACQUIRE_TIMEOUT\x10\x04\x1a\x1b\x82\xd6\x1b\x17\n\x15\x45vents/AcquireTimeout\x12\x32\n\x14\x43OUNTER_PROXY_KICKED\x10\x05\x1a\x18\x82\xd6\x1b\x14\n\x12\x45vents/ProxyKicked\x12\x36\n\x16\x43OUNTER_SESSION_STOLEN\x10\x06\x1a\x1a\x82\xd6\x1b\x16\n\x14\x45vents/SessionStolen\x12=\n\x1b\x43OUNTER_REQS_PROXY_REGISTER\x10\x07\x1a\x1c\x82\xd6\x1b\x18\n\x16Requests/ProxyRegister\x12\x41\n\x1d\x43OUNTER_REQS_PROXY_UNREGISTER\x10\x08\x1a\x1e\x82\xd6\x1b\x1a\n\x18Requests/ProxyUnregister\x12=\n\x1b\x43OUNTER_REQS_SESSION_ATTACH\x10\t\x1a\x1c\x82\xd6\x1b\x18\n\x16Requests/SessionAttach\x12?\n\x1c\x43OUNTER_REQS_SESSION_DESTROY\x10\n\x1a\x1d\x82\xd6\x1b\x19\n\x17Requests/SessionDestroy\x12=\n\x1b\x43OUNTER_REQS_SESSION_DETACH\x10\x0b\x1a\x1c\x82\xd6\x1b\x18\n\x16Requests/SessionDetach\x12\x43\n\x1e\x43OUNTER_REQS_SEMAPHORE_ACQUIRE\x10\x0c\x1a\x1f\x82\xd6\x1b\x1b\n\x19Requests/SemaphoreAcquire\x12\x41\n\x1d\x43OUNTER_REQS_SEMAPHORE_CREATE\x10\r\x1a\x1e\x82\xd6\x1b\x1a\n\x18Requests/SemaphoreCreate\x12\x41\n\x1d\x43OUNTER_REQS_SEMAPHORE_DELETE\x10\x0e\x1a\x1e\x82\xd6\x1b\x1a\n\x18Requests/SemaphoreDelete\x12\x43\n\x1e\x43OUNTER_REQS_SEMAPHORE_RELEASE\x10\x0f\x1a\x1f\x82\xd6\x1b\x1b\n\x19Requests/SemaphoreRelease\x12P\n%COUNTER_REQS_QUOTER_RESOURCE_DESCRIBE\x10\x10\x1a%\x82\xd6\x1b!\n\x1fRequests/QuoterResourceDescribe\x12\x46\n COUNTER_REQS_QUOTER_RESOURCE_ADD\x10\x11\x1a \x82\xd6\x1b\x1c\n\x1aRequests/QuoterResourceAdd\x12L\n#COUNTER_REQS_QUOTER_RESOURCE_UPDATE\x10\x12\x1a#\x82\xd6\x1b\x1f\n\x1dRequests/QuoterResourceUpdate\x12L\n#COUNTER_REQS_QUOTER_RESOURCE_DELETE\x10\x13\x1a#\x82\xd6\x1b\x1f\n\x1dRequests/QuoterResourceDelete*N\n\x13\x45PercentileCounters\x12\x1d\n\x19\x43OUNTER_PERCENTILE_IGNORE\x10\x00\x1a\x18\x92\xd6\x1b\x14\x12\x08\x08\x00\x12\x04\x30 ms\x12\x08\x08\x01\x12\x04\x31 ms*\xfe\x08\n\x08\x45TxTypes\x12*\n\x12TXTYPE_INIT_SCHEMA\x10\x00\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxInitSchema\x12\x1d\n\x0bTXTYPE_INIT\x10\x01\x1a\x0c\x8a\xd6\x1b\x08\n\x06TxInit\x12\x1f\n\x0cTXTYPE_DUMMY\x10\x02\x1a\r\x8a\xd6\x1b\t\n\x07TxDummy\x12(\n\x11TXTYPE_CONFIG_GET\x10\x03\x1a\x11\x8a\xd6\x1b\r\n\x0bTxConfigGet\x12(\n\x11TXTYPE_CONFIG_SET\x10\x04\x1a\x11\x8a\xd6\x1b\r\n\x0bTxConfigSet\x12\x30\n\x15TXTYPE_SESSION_ATTACH\x10\x05\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxSessionAttach\x12\x32\n\x16TXTYPE_SESSION_DESTROY\x10\x06\x1a\x16\x8a\xd6\x1b\x12\n\x10TxSessionDestroy\x12\x30\n\x15TXTYPE_SESSION_DETACH\x10\x07\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxSessionDetach\x12\x32\n\x16TXTYPE_SESSION_TIMEOUT\x10\x08\x1a\x16\x8a\xd6\x1b\x12\n\x10TxSessionTimeout\x12\x36\n\x18TXTYPE_SESSIONS_DESCRIBE\x10\t\x1a\x18\x8a\xd6\x1b\x14\n\x12TxSessionsDescribe\x12\x36\n\x18TXTYPE_SEMAPHORE_ACQUIRE\x10\n\x1a\x18\x8a\xd6\x1b\x14\n\x12TxSemaphoreAcquire\x12\x34\n\x17TXTYPE_SEMAPHORE_CREATE\x10\x0b\x1a\x17\x8a\xd6\x1b\x13\n\x11TxSemaphoreCreate\x12\x38\n\x19TXTYPE_SEMAPHORE_DESCRIBE\x10\x0c\x1a\x19\x8a\xd6\x1b\x15\n\x13TxSemaphoreDescribe\x12\x34\n\x17TXTYPE_SEMAPHORE_DELETE\x10\r\x1a\x17\x8a\xd6\x1b\x13\n\x11TxSemaphoreDelete\x12\x36\n\x18TXTYPE_SEMAPHORE_RELEASE\x10\x0e\x1a\x18\x8a\xd6\x1b\x14\n\x12TxSemaphoreRelease\x12\x36\n\x18TXTYPE_SEMAPHORE_TIMEOUT\x10\x0f\x1a\x18\x8a\xd6\x1b\x14\n\x12TxSemaphoreTimeout\x12\x34\n\x17TXTYPE_SEMAPHORE_UPDATE\x10\x10\x1a\x17\x8a\xd6\x1b\x13\n\x11TxSemaphoreUpdate\x12(\n\x11TXTYPE_SELF_CHECK\x10\x11\x1a\x11\x8a\xd6\x1b\r\n\x0bTxSelfCheck\x12\x43\n\x1fTXTYPE_QUOTER_RESOURCE_DESCRIBE\x10\x12\x1a\x1e\x8a\xd6\x1b\x1a\n\x18TxQouterResourceDescribe\x12\x39\n\x1aTXTYPE_QUOTER_RESOURCE_ADD\x10\x13\x1a\x19\x8a\xd6\x1b\x15\n\x13TxQouterResourceAdd\x12?\n\x1dTXTYPE_QUOTER_RESOURCE_UPDATE\x10\x14\x1a\x1c\x8a\xd6\x1b\x18\n\x16TxQouterResourceUpdate\x12?\n\x1dTXTYPE_QUOTER_RESOURCE_DELETE\x10\x15\x1a\x1c\x8a\xd6\x1b\x18\n\x16TxQouterResourceDeleteB!\n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\x05Kesus')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_kesus_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\005Kesus'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PROXY_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PROXY_COUNT"]._serialized_options = b'\202\326\033\t\n\007Proxies'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SESSION_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SESSION_COUNT"]._serialized_options = b'\202\326\033\n\n\010Sessions'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SESSION_ACTIVE_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SESSION_ACTIVE_COUNT"]._serialized_options = b'\202\326\033\020\n\016ActiveSessions'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SEMAPHORE_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SEMAPHORE_COUNT"]._serialized_options = b'\202\326\033\014\n\nSemaphores'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SEMAPHORE_OWNER_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SEMAPHORE_OWNER_COUNT"]._serialized_options = b'\202\326\033\021\n\017SemaphoreOwners'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SEMAPHORE_WAITER_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SEMAPHORE_WAITER_COUNT"]._serialized_options = b'\202\326\033\022\n\020SemaphoreWaiters'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_QUOTER_RESOURCE_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_QUOTER_RESOURCE_COUNT"]._serialized_options = b'\202\326\033\021\n\017QuoterResources'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SCHEDULED_SESSION_TIMEOUT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SCHEDULED_SESSION_TIMEOUT"]._serialized_options = b'\202\326\033 \n\036Events/ScheduledSessionTimeout'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SCHEDULED_ACQUIRE_TIMEOUT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SCHEDULED_ACQUIRE_TIMEOUT"]._serialized_options = b'\202\326\033 \n\036Events/ScheduledAcquireTimeout'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SESSION_TIMEOUT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SESSION_TIMEOUT"]._serialized_options = b'\202\326\033\027\n\025Events/SessionTimeout'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ACQUIRE_TIMEOUT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ACQUIRE_TIMEOUT"]._serialized_options = b'\202\326\033\027\n\025Events/AcquireTimeout'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PROXY_KICKED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PROXY_KICKED"]._serialized_options = b'\202\326\033\024\n\022Events/ProxyKicked'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SESSION_STOLEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SESSION_STOLEN"]._serialized_options = b'\202\326\033\026\n\024Events/SessionStolen'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_PROXY_REGISTER"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_PROXY_REGISTER"]._serialized_options = b'\202\326\033\030\n\026Requests/ProxyRegister'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_PROXY_UNREGISTER"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_PROXY_UNREGISTER"]._serialized_options = b'\202\326\033\032\n\030Requests/ProxyUnregister'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SESSION_ATTACH"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SESSION_ATTACH"]._serialized_options = b'\202\326\033\030\n\026Requests/SessionAttach'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SESSION_DESTROY"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SESSION_DESTROY"]._serialized_options = b'\202\326\033\031\n\027Requests/SessionDestroy'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SESSION_DETACH"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SESSION_DETACH"]._serialized_options = b'\202\326\033\030\n\026Requests/SessionDetach'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SEMAPHORE_ACQUIRE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SEMAPHORE_ACQUIRE"]._serialized_options = b'\202\326\033\033\n\031Requests/SemaphoreAcquire'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SEMAPHORE_CREATE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SEMAPHORE_CREATE"]._serialized_options = b'\202\326\033\032\n\030Requests/SemaphoreCreate'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SEMAPHORE_DELETE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SEMAPHORE_DELETE"]._serialized_options = b'\202\326\033\032\n\030Requests/SemaphoreDelete'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SEMAPHORE_RELEASE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SEMAPHORE_RELEASE"]._serialized_options = b'\202\326\033\033\n\031Requests/SemaphoreRelease'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_QUOTER_RESOURCE_DESCRIBE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_QUOTER_RESOURCE_DESCRIBE"]._serialized_options = b'\202\326\033!\n\037Requests/QuoterResourceDescribe'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_QUOTER_RESOURCE_ADD"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_QUOTER_RESOURCE_ADD"]._serialized_options = b'\202\326\033\034\n\032Requests/QuoterResourceAdd'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_QUOTER_RESOURCE_UPDATE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_QUOTER_RESOURCE_UPDATE"]._serialized_options = b'\202\326\033\037\n\035Requests/QuoterResourceUpdate'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_QUOTER_RESOURCE_DELETE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_QUOTER_RESOURCE_DELETE"]._serialized_options = b'\202\326\033\037\n\035Requests/QuoterResourceDelete'
  _EPERCENTILECOUNTERS._options = None
  _EPERCENTILECOUNTERS._serialized_options = b'\222\326\033\024\022\010\010\000\022\0040 ms\022\010\010\001\022\0041 ms'
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._serialized_options = b'\212\326\033\016\n\014TxInitSchema'
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._serialized_options = b'\212\326\033\010\n\006TxInit'
  _ETXTYPES.values_by_name["TXTYPE_DUMMY"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DUMMY"]._serialized_options = b'\212\326\033\t\n\007TxDummy'
  _ETXTYPES.values_by_name["TXTYPE_CONFIG_GET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CONFIG_GET"]._serialized_options = b'\212\326\033\r\n\013TxConfigGet'
  _ETXTYPES.values_by_name["TXTYPE_CONFIG_SET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CONFIG_SET"]._serialized_options = b'\212\326\033\r\n\013TxConfigSet'
  _ETXTYPES.values_by_name["TXTYPE_SESSION_ATTACH"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SESSION_ATTACH"]._serialized_options = b'\212\326\033\021\n\017TxSessionAttach'
  _ETXTYPES.values_by_name["TXTYPE_SESSION_DESTROY"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SESSION_DESTROY"]._serialized_options = b'\212\326\033\022\n\020TxSessionDestroy'
  _ETXTYPES.values_by_name["TXTYPE_SESSION_DETACH"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SESSION_DETACH"]._serialized_options = b'\212\326\033\021\n\017TxSessionDetach'
  _ETXTYPES.values_by_name["TXTYPE_SESSION_TIMEOUT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SESSION_TIMEOUT"]._serialized_options = b'\212\326\033\022\n\020TxSessionTimeout'
  _ETXTYPES.values_by_name["TXTYPE_SESSIONS_DESCRIBE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SESSIONS_DESCRIBE"]._serialized_options = b'\212\326\033\024\n\022TxSessionsDescribe'
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_ACQUIRE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_ACQUIRE"]._serialized_options = b'\212\326\033\024\n\022TxSemaphoreAcquire'
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_CREATE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_CREATE"]._serialized_options = b'\212\326\033\023\n\021TxSemaphoreCreate'
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_DESCRIBE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_DESCRIBE"]._serialized_options = b'\212\326\033\025\n\023TxSemaphoreDescribe'
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_DELETE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_DELETE"]._serialized_options = b'\212\326\033\023\n\021TxSemaphoreDelete'
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_RELEASE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_RELEASE"]._serialized_options = b'\212\326\033\024\n\022TxSemaphoreRelease'
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_TIMEOUT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_TIMEOUT"]._serialized_options = b'\212\326\033\024\n\022TxSemaphoreTimeout'
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_UPDATE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_UPDATE"]._serialized_options = b'\212\326\033\023\n\021TxSemaphoreUpdate'
  _ETXTYPES.values_by_name["TXTYPE_SELF_CHECK"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SELF_CHECK"]._serialized_options = b'\212\326\033\r\n\013TxSelfCheck'
  _ETXTYPES.values_by_name["TXTYPE_QUOTER_RESOURCE_DESCRIBE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_QUOTER_RESOURCE_DESCRIBE"]._serialized_options = b'\212\326\033\032\n\030TxQouterResourceDescribe'
  _ETXTYPES.values_by_name["TXTYPE_QUOTER_RESOURCE_ADD"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_QUOTER_RESOURCE_ADD"]._serialized_options = b'\212\326\033\025\n\023TxQouterResourceAdd'
  _ETXTYPES.values_by_name["TXTYPE_QUOTER_RESOURCE_UPDATE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_QUOTER_RESOURCE_UPDATE"]._serialized_options = b'\212\326\033\030\n\026TxQouterResourceUpdate'
  _ETXTYPES.values_by_name["TXTYPE_QUOTER_RESOURCE_DELETE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_QUOTER_RESOURCE_DELETE"]._serialized_options = b'\212\326\033\030\n\026TxQouterResourceDelete'
  _ESIMPLECOUNTERS._serialized_start=89
  _ESIMPLECOUNTERS._serialized_end=495
  _ECUMULATIVECOUNTERS._serialized_start=498
  _ECUMULATIVECOUNTERS._serialized_end=1831
  _EPERCENTILECOUNTERS._serialized_start=1833
  _EPERCENTILECOUNTERS._serialized_end=1911
  _ETXTYPES._serialized_start=1914
  _ETXTYPES._serialized_end=3064
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/console_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.core.protos import config_pb2 as ydb_dot_core_dot_protos_dot_config__pb2
from ydb.core.protos import console_base_pb2 as ydb_dot_core_dot_protos_dot_console__base__pb2
from ydb.public.api.protos import ydb_status_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__status__codes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ydb/core/protos/console_config.proto\x12\x0eNKikimrConsole\x1a&library/cpp/actors/protos/actors.proto\x1a\x1cydb/core/protos/config.proto\x1a\"ydb/core/protos/console_base.proto\x1a,ydb/public/api/protos/ydb_status_codes.proto\"/\n\rTConfigItemId\x12\n\n\x02Id\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\x04\"\x17\n\x08TItemIds\x12\x0b\n\x03Ids\x18\x01 \x03(\x04\"\x19\n\x08TNodeIds\x12\r\n\x05Nodes\x18\x01 \x03(\r\"\x17\n\x06THosts\x12\r\n\x05Hosts\x18\x01 \x03(\t\"\x1b\n\x08TTenants\x12\x0f\n\x07Tenants\x18\x01 \x03(\t\"\x1f\n\nTNodeTypes\x12\x11\n\tNodeTypes\x18\x01 \x03(\t\"6\n\x12TTenantAndNodeType\x12\x0e\n\x06Tenant\x18\x01 \x01(\t\x12\x10\n\x08NodeType\x18\x02 \x01(\t\"U\n\x13TTenantAndNodeTypes\x12>\n\x12TenantAndNodeTypes\x18\x01 \x03(\x0b\x32\".NKikimrConsole.TTenantAndNodeType\"\x1b\n\x08TCookies\x12\x0f\n\x07\x43ookies\x18\x01 \x03(\t\"\xbc\x01\n\x0bTUsageScope\x12.\n\nNodeFilter\x18\x01 \x01(\x0b\x32\x18.NKikimrConsole.TNodeIdsH\x00\x12,\n\nHostFilter\x18\x02 \x01(\x0b\x32\x16.NKikimrConsole.THostsH\x00\x12\x45\n\x17TenantAndNodeTypeFilter\x18\x03 \x01(\x0b\x32\".NKikimrConsole.TTenantAndNodeTypeH\x00\x42\x08\n\x06\x46ilter\"Q\n\x0fTNodeAttributes\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x0c\n\x04Host\x18\x02 \x01(\t\x12\x0e\n\x06Tenant\x18\x03 \x01(\t\x12\x10\n\x08NodeType\x18\x04 \x01(\t\"\xfe\x0c\n\x0bTConfigItem\x12)\n\x02Id\x18\x01 \x01(\x0b\x32\x1d.NKikimrConsole.TConfigItemId\x12\x0c\n\x04Kind\x18\x02 \x01(\r\x12)\n\x06\x43onfig\x18\x03 \x01(\x0b\x32\x19.NKikimrConfig.TAppConfig\x12/\n\nUsageScope\x18\x04 \x01(\x0b\x32\x1b.NKikimrConsole.TUsageScope\x12\r\n\x05Order\x18\x05 \x01(\r\x12\x18\n\rMergeStrategy\x18\x06 \x01(\r:\x01\x32\x12\x0e\n\x06\x43ookie\x18\x07 \x01(\t\"\xd6\n\n\x05\x45Kind\x12\x08\n\x04\x41uto\x10\x00\x12\x19\n\x15\x41\x63torSystemConfigItem\x10\x01\x12\x11\n\rLogConfigItem\x10\x02\x12\x19\n\x15NameserviceConfigItem\x10\x03\x12\x1a\n\x16InterconnectConfigItem\x10\x04\x12\x15\n\x11\x44omainsConfigItem\x10\x05\x12\x19\n\x15\x42lobStorageConfigItem\x10\x06\x12\x1c\n\x18\x43hannelProfileConfigItem\x10\x07\x12\x17\n\x13\x42ootstrapConfigItem\x10\x08\x12\x18\n\x14MonitoringConfigItem\x10\n\x12\x1b\n\x17RestartsCountConfigItem\x10\x0b\x12\x18\n\x14MessageBusConfigItem\x10\x0c\x12\x15\n\x11TabletsConfigItem\x10\r\x12\x13\n\x0fVDiskConfigItem\x10\x0e\x12\x18\n\x14\x44riveModelConfigItem\x10\x1f\x12\x16\n\x12IncrHugeConfigItem\x10\x12\x12\x0f\n\x0bUDFsDirItem\x10\x0f\x12\x11\n\rUDFsPathsItem\x10\x10\x12\x11\n\rKQPConfigItem\x10\x11\x12\x17\n\x13MemoryLogConfigItem\x10\x13\x12\x12\n\x0eGRpcConfigItem\x10\x14\x12 \n\x1c\x44ynamicNameserviceConfigItem\x10\x16\x12\x19\n\x15\x44ynamicNodeConfigItem\x10\x18\x12\x11\n\rCmsConfigItem\x10\x19\x12\x14\n\x10\x46\x65\x61tureFlagsItem\x10\x1a\x12\x11\n\rSqsConfigItem\x10\x1b\x12\x10\n\x0cPQConfigItem\x10\x1c\x12\x18\n\x14TenantPoolConfigItem\x10\x1d\x12\x12\n\x0e\x41uthConfigItem\x10\x1e\x12\x1e\n\x1aTenantSlotBrokerConfigItem\x10 \x12\x1f\n\x1b\x43onfigsDispatcherConfigItem\x10!\x12\x1b\n\x17TableProfilesConfigItem\x10\"\x12\x11\n\rKeyConfigItem\x10#\x12\x18\n\x14NodeBrokerConfigItem\x10$\x12\x1a\n\x16TableServiceConfigItem\x10%\x12\x19\n\x15SharedCacheConfigItem\x10&\x12\x1f\n\x1bImmediateControlsConfigItem\x10\'\x12\x17\n\x13\x41llocatorConfigItem\x10(\x12 \n\x1cPQClusterDiscoveryConfigItem\x10)\x12\x1b\n\x17NetClassifierConfigItem\x10*\x12(\n$NetClassifierDistributableConfigItem\x10+\x12\x1c\n\x18ResourceBrokerConfigItem\x10,\x12\x16\n\x12MeteringConfigItem\x10-\x12\x12\n\x0eHiveConfigItem\x10.\x12\x17\n\x13\x44\x61taShardConfigItem\x10\x31\x12\x1c\n\x18\x46\x65\x64\x65ratedQueryConfigItem\x10\x32\x12\x16\n\x12PDiskKeyConfigItem\x10\x33\x12\x18\n\x14\x43ompactionConfigItem\x10\x34\x12\x17\n\x13HttpProxyConfigItem\x10\x35\x12\x19\n\x15SchemeShardConfigItem\x10\x36\x12,\n(ClientCertificateAuthorizationConfigItem\x10\x37\x12\x14\n\x10NamedConfigsItem\x10\x64\x12\x19\n\x15\x43lusterYamlConfigItem\x10\x65\"H\n\x0e\x45MergeStrategy\x12\r\n\tOVERWRITE\x10\x01\x12\t\n\x05MERGE\x10\x02\x12\x1c\n\x18MERGE_OVERWRITE_REPEATED\x10\x03\"Z\n\x0eTAddConfigItem\x12/\n\nConfigItem\x18\x01 \x01(\x0b\x32\x1b.NKikimrConsole.TConfigItem\x12\x17\n\x0f\x45nableAutoSplit\x18\x02 \x01(\x08\"H\n\x11TRemoveConfigItem\x12\x33\n\x0c\x43onfigItemId\x18\x01 \x01(\x0b\x32\x1d.NKikimrConsole.TConfigItemId\"P\n\x12TRemoveConfigItems\x12\x30\n\x0c\x43ookieFilter\x18\x01 \x01(\x0b\x32\x18.NKikimrConsole.TCookiesH\x00\x42\x08\n\x06\x46ilter\"D\n\x11TModifyConfigItem\x12/\n\nConfigItem\x18\x01 \x01(\x0b\x32\x1b.NKikimrConsole.TConfigItem\"\x94\x02\n\x10TConfigureAction\x12\x37\n\rAddConfigItem\x18\x01 \x01(\x0b\x32\x1e.NKikimrConsole.TAddConfigItemH\x00\x12=\n\x10RemoveConfigItem\x18\x02 \x01(\x0b\x32!.NKikimrConsole.TRemoveConfigItemH\x00\x12=\n\x10ModifyConfigItem\x18\x03 \x01(\x0b\x32!.NKikimrConsole.TModifyConfigItemH\x00\x12?\n\x11RemoveConfigItems\x18\x04 \x01(\x0b\x32\".NKikimrConsole.TRemoveConfigItemsH\x00\x42\x08\n\x06\x41\x63tion\"\x86\x01\n\x11TConfigureRequest\x12\x31\n\x07\x41\x63tions\x18\x01 \x03(\x0b\x32 .NKikimrConsole.TConfigureAction\x12\x0e\n\x06\x44ryRun\x18\x02 \x01(\x08\x12\x1b\n\x13\x46illAffectedConfigs\x18\x03 \x01(\x08\x12\x11\n\tUserToken\x18\x04 \x01(\x0c\"\xb2\x02\n\x12TConfigureResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\x12\x14\n\x0c\x41\x64\x64\x65\x64ItemIds\x18\x02 \x03(\x04\x12K\n\x0f\x41\x66\x66\x65\x63tedConfigs\x18\x03 \x03(\x0b\x32\x32.NKikimrConsole.TConfigureResponse.TAffectedConfig\x1a\x8f\x01\n\x0fTAffectedConfig\x12\x0e\n\x06Tenant\x18\x01 \x01(\t\x12\x10\n\x08NodeType\x18\x02 \x01(\t\x12,\n\tOldConfig\x18\x03 \x01(\x0b\x32\x19.NKikimrConfig.TAppConfig\x12,\n\tNewConfig\x18\x04 \x01(\x0b\x32\x19.NKikimrConfig.TAppConfig\"\xa2\x03\n\x16TGetConfigItemsRequest\x12\x0f\n\x07ItemIds\x18\x01 \x03(\x04\x12,\n\nNodeFilter\x18\x02 \x01(\x0b\x32\x18.NKikimrConsole.TNodeIds\x12*\n\nHostFilter\x18\x03 \x01(\x0b\x32\x16.NKikimrConsole.THosts\x12.\n\x0cTenantFilter\x18\x04 \x01(\x0b\x32\x18.NKikimrConsole.TTenants\x12\x32\n\x0eNodeTypeFilter\x18\x05 \x01(\x0b\x32\x1a.NKikimrConsole.TNodeTypes\x12\x44\n\x17TenantAndNodeTypeFilter\x18\x06 \x01(\x0b\x32#.NKikimrConsole.TTenantAndNodeTypes\x12\x30\n\x0bUsageScopes\x18\x07 \x03(\x0b\x32\x1b.NKikimrConsole.TUsageScope\x12.\n\x0c\x43ookieFilter\x18\x08 \x01(\x0b\x32\x18.NKikimrConsole.TCookies\x12\x11\n\tItemKinds\x18\n \x03(\r\"t\n\x17TGetConfigItemsResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\x12\x30\n\x0b\x43onfigItems\x18\x02 \x03(\x0b\x32\x1b.NKikimrConsole.TConfigItem\"^\n\x1aTGetNodeConfigItemsRequest\x12-\n\x04Node\x18\x01 \x01(\x0b\x32\x1f.NKikimrConsole.TNodeAttributes\x12\x11\n\tItemKinds\x18\x02 \x03(\r\"x\n\x1bTGetNodeConfigItemsResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\x12\x30\n\x0b\x43onfigItems\x18\x02 \x03(\x0b\x32\x1b.NKikimrConsole.TConfigItem\"Y\n\x15TGetNodeConfigRequest\x12-\n\x04Node\x18\x01 \x01(\x0b\x32\x1f.NKikimrConsole.TNodeAttributes\x12\x11\n\tItemKinds\x18\x02 \x03(\r\"l\n\x16TGetNodeConfigResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\x12)\n\x06\x43onfig\x18\x02 \x01(\x0b\x32\x19.NKikimrConfig.TAppConfig\"\\\n\x0bTSubscriber\x12\x12\n\x08TabletId\x18\x01 \x01(\x04H\x00\x12+\n\tServiceId\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorIdH\x00\x42\x0c\n\nSubscriber\";\n\tTConfigId\x12.\n\x07ItemIds\x18\x01 \x03(\x0b\x32\x1d.NKikimrConsole.TConfigItemId\"\xb0\x01\n\x1aTConfigSubscriptionRequest\x12\x12\n\nGeneration\x18\x01 \x01(\x04\x12\x30\n\x07Options\x18\x02 \x01(\x0b\x32\x1f.NKikimrConsole.TNodeAttributes\x12\x17\n\x0f\x43onfigItemKinds\x18\x03 \x03(\r\x12\x33\n\x0cKnownVersion\x18\x04 \x01(\x0b\x32\x1d.NKikimrConfig.TConfigVersion\"Z\n\x1bTConfigSubscriptionResponse\x12\x12\n\nGeneration\x18\x01 \x01(\x04\x12\'\n\x06Status\x18\x02 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\"S\n\x18TConfigSubscriptionError\x12\'\n\x04\x43ode\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\x0e\n\x06Reason\x18\x03 \x01(\t\"1\n\x1bTConfigSubscriptionCanceled\x12\x12\n\nGeneration\x18\x01 \x01(\x04\"\x86\x01\n\x1fTConfigSubscriptionNotification\x12\r\n\x05Order\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12)\n\x06\x43onfig\x18\x03 \x01(\x0b\x32\x19.NKikimrConfig.TAppConfig\x12\x15\n\rAffectedKinds\x18\x04 \x03(\r\"\x97\x01\n\rTSubscription\x12\n\n\x02Id\x18\x01 \x01(\x04\x12/\n\nSubscriber\x18\x02 \x01(\x0b\x32\x1b.NKikimrConsole.TSubscriber\x12\x30\n\x07Options\x18\x03 \x01(\x0b\x32\x1f.NKikimrConsole.TNodeAttributes\x12\x17\n\x0f\x43onfigItemKinds\x18\x04 \x03(\r\"T\n\x1dTAddConfigSubscriptionRequest\x12\x33\n\x0cSubscription\x18\x01 \x01(\x0b\x32\x1d.NKikimrConsole.TSubscription\"a\n\x1eTAddConfigSubscriptionResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\x12\x16\n\x0eSubscriptionId\x18\x02 \x01(\x04\"7\n\x1dTGetConfigSubscriptionRequest\x12\x16\n\x0eSubscriptionId\x18\x01 \x01(\x04\"~\n\x1eTGetConfigSubscriptionResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\x12\x33\n\x0cSubscription\x18\x02 \x01(\x0b\x32\x1d.NKikimrConsole.TSubscription\"R\n\x1fTListConfigSubscriptionsRequest\x12/\n\nSubscriber\x18\x01 \x01(\x0b\x32\x1b.NKikimrConsole.TSubscriber\"\x81\x01\n TListConfigSubscriptionsResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\x12\x34\n\rSubscriptions\x18\x02 \x03(\x0b\x32\x1d.NKikimrConsole.TSubscription\":\n TRemoveConfigSubscriptionRequest\x12\x16\n\x0eSubscriptionId\x18\x01 \x01(\x04\"L\n!TRemoveConfigSubscriptionResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\"T\n!TRemoveConfigSubscriptionsRequest\x12/\n\nSubscriber\x18\x01 \x01(\x0b\x32\x1b.NKikimrConsole.TSubscriber\"M\n\"TRemoveConfigSubscriptionsResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\"Y\n\"TReplaceConfigSubscriptionsRequest\x12\x33\n\x0cSubscription\x18\x01 \x01(\x0b\x32\x1d.NKikimrConsole.TSubscription\"f\n#TReplaceConfigSubscriptionsResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\x12\x16\n\x0eSubscriptionId\x18\x02 \x01(\x04\"\x8c\x01\n\x1aTConfigNotificationRequest\x12\x16\n\x0eSubscriptionId\x18\x01 \x01(\x04\x12+\n\x08\x43onfigId\x18\x02 \x01(\x0b\x32\x19.NKikimrConsole.TConfigId\x12)\n\x06\x43onfig\x18\x03 \x01(\x0b\x32\x19.NKikimrConfig.TAppConfig\"b\n\x1bTConfigNotificationResponse\x12\x16\n\x0eSubscriptionId\x18\x01 \x01(\x04\x12+\n\x08\x43onfigId\x18\x02 \x01(\x0b\x32\x19.NKikimrConsole.TConfigId\"P\n\x1aTCheckConfigUpdatesRequest\x12\x32\n\x0b\x42\x61seItemIds\x18\x01 \x03(\x0b\x32\x1d.NKikimrConsole.TConfigItemId\"\xe3\x01\n\x1bTCheckConfigUpdatesResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\x12\x31\n\nAddedItems\x18\x02 \x03(\x0b\x32\x1d.NKikimrConsole.TConfigItemId\x12\x33\n\x0cRemovedItems\x18\x03 \x03(\x0b\x32\x1d.NKikimrConsole.TConfigItemId\x12\x33\n\x0cUpdatedItems\x18\x04 \x03(\x0b\x32\x1d.NKikimrConsole.TConfigItemId\"\x1e\n\x1cTListConfigValidatorsRequest\"d\n\x14TConfigValidatorInfo\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x13\n\x0b\x44\x65scription\x18\x02 \x01(\t\x12\x18\n\x10\x43heckedItemKinds\x18\x03 \x03(\r\x12\x0f\n\x07\x45nabled\x18\x04 \x01(\x08\"\x82\x01\n\x1dTListConfigValidatorsResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\x12\x38\n\nValidators\x18\x02 \x03(\x0b\x32$.NKikimrConsole.TConfigValidatorInfo\">\n\x1dTToggleConfigValidatorRequest\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0f\n\x07\x44isable\x18\x02 \x01(\x08\"I\n\x1eTToggleConfigValidatorResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\"\xba\x05\n\x0eTConfigsConfig\x12V\n\x16UsageScopeRestrictions\x18\x01 \x01(\x0b\x32\x36.NKikimrConsole.TConfigsConfig.TUsageScopeRestrictions\x12L\n\x11ValidationOptions\x18\x02 \x01(\x0b\x32\x31.NKikimrConsole.TConfigsConfig.TValidationOptions\x1a\xda\x01\n\x17TUsageScopeRestrictions\x12$\n\x1c\x41llowedNodeIdUsageScopeKinds\x18\x01 \x03(\r\x12\"\n\x1a\x41llowedHostUsageScopeKinds\x18\x02 \x03(\r\x12$\n\x1c\x41llowedTenantUsageScopeKinds\x18\x03 \x03(\r\x12&\n\x1e\x41llowedNodeTypeUsageScopeKinds\x18\x04 \x03(\r\x12\'\n\x1f\x44isallowedDomainUsageScopeKinds\x18\x05 \x03(\r\x1a\xa4\x02\n\x12TValidationOptions\x12Z\n\x0fValidationLevel\x18\x01 \x01(\x0e\x32 .NKikimrConsole.EValidationLevel:\x1fVALIDATE_TENANTS_AND_NODE_TYPES\x12-\n\x1eMaxConfigChecksPerModification\x18\x02 \x01(\r:\x05\x31\x30\x30\x30\x30\x12-\n\x1f\x46\x61ilOnExceededConfigChecksLimit\x18\x03 \x01(\x08:\x04true\x12\x31\n#EnableValidationOnNodeConfigRequest\x18\x04 \x01(\x08:\x04true\x12!\n\x13TreatWarningAsError\x18\x05 \x01(\x08:\x04true*u\n\x10\x45ValidationLevel\x12\x11\n\rVALIDATE_NONE\x10\x00\x12\x13\n\x0fVALIDATE_DOMAIN\x10\x01\x12\x14\n\x10VALIDATE_TENANTS\x10\x02\x12#\n\x1fVALIDATE_TENANTS_AND_NODE_TYPES\x10\x03\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.console_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _EVALIDATIONLEVEL._serialized_start=8107
  _EVALIDATIONLEVEL._serialized_end=8224
  _TCONFIGITEMID._serialized_start=208
  _TCONFIGITEMID._serialized_end=255
  _TITEMIDS._serialized_start=257
  _TITEMIDS._serialized_end=280
  _TNODEIDS._serialized_start=282
  _TNODEIDS._serialized_end=307
  _THOSTS._serialized_start=309
  _THOSTS._serialized_end=332
  _TTENANTS._serialized_start=334
  _TTENANTS._serialized_end=361
  _TNODETYPES._serialized_start=363
  _TNODETYPES._serialized_end=394
  _TTENANTANDNODETYPE._serialized_start=396
  _TTENANTANDNODETYPE._serialized_end=450
  _TTENANTANDNODETYPES._serialized_start=452
  _TTENANTANDNODETYPES._serialized_end=537
  _TCOOKIES._serialized_start=539
  _TCOOKIES._serialized_end=566
  _TUSAGESCOPE._serialized_start=569
  _TUSAGESCOPE._serialized_end=757
  _TNODEATTRIBUTES._serialized_start=759
  _TNODEATTRIBUTES._serialized_end=840
  _TCONFIGITEM._serialized_start=843
  _TCONFIGITEM._serialized_end=2505
  _TCONFIGITEM_EKIND._serialized_start=1065
  _TCONFIGITEM_EKIND._serialized_end=2431
  _TCONFIGITEM_EMERGESTRATEGY._serialized_start=2433
  _TCONFIGITEM_EMERGESTRATEGY._serialized_end=2505
  _TADDCONFIGITEM._serialized_start=2507
  _TADDCONFIGITEM._serialized_end=2597
  _TREMOVECONFIGITEM._serialized_start=2599
  _TREMOVECONFIGITEM._serialized_end=2671
  _TREMOVECONFIGITEMS._serialized_start=2673
  _TREMOVECONFIGITEMS._serialized_end=2753
  _TMODIFYCONFIGITEM._serialized_start=2755
  _TMODIFYCONFIGITEM._serialized_end=2823
  _TCONFIGUREACTION._serialized_start=2826
  _TCONFIGUREACTION._serialized_end=3102
  _TCONFIGUREREQUEST._serialized_start=3105
  _TCONFIGUREREQUEST._serialized_end=3239
  _TCONFIGURERESPONSE._serialized_start=3242
  _TCONFIGURERESPONSE._serialized_end=3548
  _TCONFIGURERESPONSE_TAFFECTEDCONFIG._serialized_start=3405
  _TCONFIGURERESPONSE_TAFFECTEDCONFIG._serialized_end=3548
  _TGETCONFIGITEMSREQUEST._serialized_start=3551
  _TGETCONFIGITEMSREQUEST._serialized_end=3969
  _TGETCONFIGITEMSRESPONSE._serialized_start=3971
  _TGETCONFIGITEMSRESPONSE._serialized_end=4087
  _TGETNODECONFIGITEMSREQUEST._serialized_start=4089
  _TGETNODECONFIGITEMSREQUEST._serialized_end=4183
  _TGETNODECONFIGITEMSRESPONSE._serialized_start=4185
  _TGETNODECONFIGITEMSRESPONSE._serialized_end=4305
  _TGETNODECONFIGREQUEST._serialized_start=4307
  _TGETNODECONFIGREQUEST._serialized_end=4396
  _TGETNODECONFIGRESPONSE._serialized_start=4398
  _TGETNODECONFIGRESPONSE._serialized_end=4506
  _TSUBSCRIBER._serialized_start=4508
  _TSUBSCRIBER._serialized_end=4600
  _TCONFIGID._serialized_start=4602
  _TCONFIGID._serialized_end=4661
  _TCONFIGSUBSCRIPTIONREQUEST._serialized_start=4664
  _TCONFIGSUBSCRIPTIONREQUEST._serialized_end=4840
  _TCONFIGSUBSCRIPTIONRESPONSE._serialized_start=4842
  _TCONFIGSUBSCRIPTIONRESPONSE._serialized_end=4932
  _TCONFIGSUBSCRIPTIONERROR._serialized_start=4934
  _TCONFIGSUBSCRIPTIONERROR._serialized_end=5017
  _TCONFIGSUBSCRIPTIONCANCELED._serialized_start=5019
  _TCONFIGSUBSCRIPTIONCANCELED._serialized_end=5068
  _TCONFIGSUBSCRIPTIONNOTIFICATION._serialized_start=5071
  _TCONFIGSUBSCRIPTIONNOTIFICATION._serialized_end=5205
  _TSUBSCRIPTION._serialized_start=5208
  _TSUBSCRIPTION._serialized_end=5359
  _TADDCONFIGSUBSCRIPTIONREQUEST._serialized_start=5361
  _TADDCONFIGSUBSCRIPTIONREQUEST._serialized_end=5445
  _TADDCONFIGSUBSCRIPTIONRESPONSE._serialized_start=5447
  _TADDCONFIGSUBSCRIPTIONRESPONSE._serialized_end=5544
  _TGETCONFIGSUBSCRIPTIONREQUEST._serialized_start=5546
  _TGETCONFIGSUBSCRIPTIONREQUEST._serialized_end=5601
  _TGETCONFIGSUBSCRIPTIONRESPONSE._serialized_start=5603
  _TGETCONFIGSUBSCRIPTIONRESPONSE._serialized_end=5729
  _TLISTCONFIGSUBSCRIPTIONSREQUEST._serialized_start=5731
  _TLISTCONFIGSUBSCRIPTIONSREQUEST._serialized_end=5813
  _TLISTCONFIGSUBSCRIPTIONSRESPONSE._serialized_start=5816
  _TLISTCONFIGSUBSCRIPTIONSRESPONSE._serialized_end=5945
  _TREMOVECONFIGSUBSCRIPTIONREQUEST._serialized_start=5947
  _TREMOVECONFIGSUBSCRIPTIONREQUEST._serialized_end=6005
  _TREMOVECONFIGSUBSCRIPTIONRESPONSE._serialized_start=6007
  _TREMOVECONFIGSUBSCRIPTIONRESPONSE._serialized_end=6083
  _TREMOVECONFIGSUBSCRIPTIONSREQUEST._serialized_start=6085
  _TREMOVECONFIGSUBSCRIPTIONSREQUEST._serialized_end=6169
  _TREMOVECONFIGSUBSCRIPTIONSRESPONSE._serialized_start=6171
  _TREMOVECONFIGSUBSCRIPTIONSRESPONSE._serialized_end=6248
  _TREPLACECONFIGSUBSCRIPTIONSREQUEST._serialized_start=6250
  _TREPLACECONFIGSUBSCRIPTIONSREQUEST._serialized_end=6339
  _TREPLACECONFIGSUBSCRIPTIONSRESPONSE._serialized_start=6341
  _TREPLACECONFIGSUBSCRIPTIONSRESPONSE._serialized_end=6443
  _TCONFIGNOTIFICATIONREQUEST._serialized_start=6446
  _TCONFIGNOTIFICATIONREQUEST._serialized_end=6586
  _TCONFIGNOTIFICATIONRESPONSE._serialized_start=6588
  _TCONFIGNOTIFICATIONRESPONSE._serialized_end=6686
  _TCHECKCONFIGUPDATESREQUEST._serialized_start=6688
  _TCHECKCONFIGUPDATESREQUEST._serialized_end=6768
  _TCHECKCONFIGUPDATESRESPONSE._serialized_start=6771
  _TCHECKCONFIGUPDATESRESPONSE._serialized_end=6998
  _TLISTCONFIGVALIDATORSREQUEST._serialized_start=7000
  _TLISTCONFIGVALIDATORSREQUEST._serialized_end=7030
  _TCONFIGVALIDATORINFO._serialized_start=7032
  _TCONFIGVALIDATORINFO._serialized_end=7132
  _TLISTCONFIGVALIDATORSRESPONSE._serialized_start=7135
  _TLISTCONFIGVALIDATORSRESPONSE._serialized_end=7265
  _TTOGGLECONFIGVALIDATORREQUEST._serialized_start=7267
  _TTOGGLECONFIGVALIDATORREQUEST._serialized_end=7329
  _TTOGGLECONFIGVALIDATORRESPONSE._serialized_start=7331
  _TTOGGLECONFIGVALIDATORRESPONSE._serialized_end=7404
  _TCONFIGSCONFIG._serialized_start=7407
  _TCONFIGSCONFIG._serialized_end=8105
  _TCONFIGSCONFIG_TUSAGESCOPERESTRICTIONS._serialized_start=7592
  _TCONFIGSCONFIG_TUSAGESCOPERESTRICTIONS._serialized_end=7810
  _TCONFIGSCONFIG_TVALIDATIONOPTIONS._serialized_start=7813
  _TCONFIGSCONFIG_TVALIDATIONOPTIONS._serialized_end=8105
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: library/cpp/actors/protos/unittests.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)library/cpp/actors/protos/unittests.proto\"6\n\x07TSimple\x12\x0c\n\x04Str1\x18\x01 \x02(\t\x12\x0c\n\x04Str2\x18\x02 \x01(\t\x12\x0f\n\x07Number1\x18\x03 \x01(\x04\"_\n\x0bTBigMessage\x12\x19\n\x07Simples\x18\x01 \x03(\x0b\x32\x08.TSimple\x12\x0f\n\x07ManyStr\x18\x02 \x03(\t\x12\x12\n\nOneMoreStr\x18\x03 \x01(\t\x12\x10\n\x08YANumber\x18\x04 \x01(\x04\"H\n\x13TMessageWithPayload\x12\x0c\n\x04Meta\x18\x01 \x01(\t\x12\x11\n\tPayloadId\x18\x02 \x03(\r\x12\x10\n\x08SomeData\x18\x03 \x03(\x0c\x42\x03\xf8\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'library.cpp.actors.protos.unittests_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _TSIMPLE._serialized_start=45
  _TSIMPLE._serialized_end=99
  _TBIGMESSAGE._serialized_start=101
  _TBIGMESSAGE._serialized_end=196
  _TMESSAGEWITHPAYLOAD._serialized_start=198
  _TMESSAGEWITHPAYLOAD._serialized_end=270
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/public/api/protos/ydb_discovery.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.public.api.protos import ydb_operation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)ydb/public/api/protos/ydb_discovery.proto\x12\rYdb.Discovery\x1a)ydb/public/api/protos/ydb_operation.proto\"9\n\x14ListEndpointsRequest\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\x0f\n\x07service\x18\x02 \x03(\t\"\xc3\x01\n\x0c\x45ndpointInfo\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x13\n\x0bload_factor\x18\x03 \x01(\x02\x12\x0b\n\x03ssl\x18\x04 \x01(\x08\x12\x0f\n\x07service\x18\x05 \x03(\t\x12\x10\n\x08location\x18\x06 \x01(\t\x12\x0f\n\x07node_id\x18\x07 \x01(\r\x12\r\n\x05ip_v4\x18\x08 \x03(\t\x12\r\n\x05ip_v6\x18\t \x03(\t\x12 \n\x18ssl_target_name_override\x18\n \x01(\t\"\\\n\x13ListEndpointsResult\x12.\n\tendpoints\x18\x01 \x03(\x0b\x32\x1b.Ydb.Discovery.EndpointInfo\x12\x15\n\rself_location\x18\x02 \x01(\t\"E\n\x15ListEndpointsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\'\n\rWhoAmIRequest\x12\x16\n\x0einclude_groups\x18\x01 \x01(\x08\",\n\x0cWhoAmIResult\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0e\n\x06groups\x18\x02 \x03(\t\">\n\x0eWhoAmIResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.OperationB.\n\x18\x63om.yandex.ydb.discoveryB\x0f\x44iscoveryProtos\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.public.api.protos.ydb_discovery_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030com.yandex.ydb.discoveryB\017DiscoveryProtos\370\001\001'
  _LISTENDPOINTSREQUEST._serialized_start=103
  _LISTENDPOINTSREQUEST._serialized_end=160
  _ENDPOINTINFO._serialized_start=163
  _ENDPOINTINFO._serialized_end=358
  _LISTENDPOINTSRESULT._serialized_start=360
  _LISTENDPOINTSRESULT._serialized_end=452
  _LISTENDPOINTSRESPONSE._serialized_start=454
  _LISTENDPOINTSRESPONSE._serialized_end=523
  _WHOAMIREQUEST._serialized_start=525
  _WHOAMIREQUEST._serialized_end=564
  _WHOAMIRESULT._serialized_start=566
  _WHOAMIRESULT._serialized_end=610
  _WHOAMIRESPONSE._serialized_start=612
  _WHOAMIRESPONSE._serialized_end=674
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/yq/libs/config/protos/control_plane_storage.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.yq.libs.config.protos import storage_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_storage__pb2
from ydb.library.yql.dq.actors.protos import dq_status_codes_pb2 as ydb_dot_library_dot_yql_dot_dq_dot_actors_dot_protos_dot_dq__status__codes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:ydb/core/yq/libs/config/protos/control_plane_storage.proto\x12\x0bNYq.NConfig\x1a,ydb/core/yq/libs/config/protos/storage.proto\x1a\x36ydb/library/yql/dq/actors/protos/dq_status_codes.proto\"&\n\x08TMapItem\x12\x0b\n\x03Key\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\t\"\x8f\x01\n\rTQueryMapping\x12\x32\n\x13\x43loudIdToTenantName\x18\x01 \x03(\x0b\x32\x15.NYq.NConfig.TMapItem\x12\x30\n\x11ScopeToTenantName\x18\x02 \x03(\x0b\x32\x15.NYq.NConfig.TMapItem\x12\x18\n\x10\x43ommonTenantName\x18\x03 \x03(\t\"N\n\x0cTRetryPolicy\x12\x12\n\nRetryCount\x18\x01 \x01(\x04\x12\x13\n\x0bRetryPeriod\x18\x02 \x01(\t\x12\x15\n\rBackoffPeriod\x18\x03 \x01(\t\"y\n\x13TRetryPolicyMapping\x12\x37\n\nStatusCode\x18\x01 \x03(\x0e\x32#.NYql.NDqProto.StatusIds.StatusCode\x12)\n\x06Policy\x18\x02 \x01(\x0b\x32\x19.NYq.NConfig.TRetryPolicy\"\xb7\x07\n\x1aTControlPlaneStorageConfig\x12\x0f\n\x07\x45nabled\x18\x01 \x01(\x08\x12/\n\x07Storage\x18\x02 \x01(\x0b\x32\x1e.NYq.NConfig.TYdbStorageConfig\x12\x1a\n\x12IdempotencyKeysTtl\x18\x03 \x01(\t\x12\x16\n\x0eMaxRequestSize\x18\x04 \x01(\x04\x12\x17\n\x0fMaxCountQueries\x18\x05 \x01(\x04\x12\x1b\n\x13MaxCountConnections\x18\x06 \x01(\x04\x12\x18\n\x10MaxCountBindings\x18\x07 \x01(\x04\x12\x14\n\x0cMaxCountJobs\x18\x08 \x01(\x04\x12\x12\n\nSuperUsers\x18\t \x03(\t\x12\x17\n\x0f\x45nableDebugMode\x18\n \x01(\x08\x12\x19\n\x11\x45nablePermissions\x18\x0b \x01(\x08\x12\x19\n\x11\x44isableCurrentIam\x18\x0c \x01(\x08\x12\x13\n\x0bUseInMemory\x18\r \x01(\x08\x12\x16\n\x0eTasksBatchSize\x18\x0e \x01(\x04\x12\x1a\n\x12NumTasksProportion\x18\x0f \x01(\x04\x12\"\n\x1a\x41nalyticsRetryCounterLimit\x18\x10 \x01(\x04\x12\"\n\x1aStreamingRetryCounterLimit\x18\x11 \x01(\x04\x12\'\n\x1f\x41nalyticsRetryCounterUpdateTime\x18\x12 \x01(\t\x12\'\n\x1fStreamingRetryCounterUpdateTime\x18\x13 \x01(\t\x12\x1b\n\x13\x41utomaticQueriesTtl\x18\x14 \x01(\t\x12\x14\n\x0cTaskLeaseTtl\x18\x15 \x01(\t\x12\x37\n\x14TaskLeaseRetryPolicy\x18\x1b \x01(\x0b\x32\x19.NYq.NConfig.TRetryPolicy\x12\x1b\n\x13\x41vailableConnection\x18\x16 \x03(\t\x12\x18\n\x10\x41vailableBinding\x18\x17 \x03(\t\x12\x15\n\rResultSetsTtl\x18\x18 \x01(\t\x12+\n\x07Mapping\x18\x19 \x01(\x0b\x32\x1a.NYq.NConfig.TQueryMapping\x12<\n\x12RetryPolicyMapping\x18\x1a \x03(\x0b\x32 .NYq.NConfig.TRetryPolicyMapping\x12\x10\n\x08QuotaTtl\x18\x1c \x01(\t\x12\x12\n\nMetricsTtl\x18\x1d \x01(\t\x12\x14\n\x0cUseDbMapping\x18\x1e \x01(\x08\x12\x16\n\x0e\x44\x62ReloadPeriod\x18\x1f \x01(\tB\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.yq.libs.config.protos.control_plane_storage_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TMAPITEM._serialized_start=177
  _TMAPITEM._serialized_end=215
  _TQUERYMAPPING._serialized_start=218
  _TQUERYMAPPING._serialized_end=361
  _TRETRYPOLICY._serialized_start=363
  _TRETRYPOLICY._serialized_end=441
  _TRETRYPOLICYMAPPING._serialized_start=443
  _TRETRYPOLICYMAPPING._serialized_end=564
  _TCONTROLPLANESTORAGECONFIG._serialized_start=567
  _TCONTROLPLANESTORAGECONFIG._serialized_end=1518
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/blobstorage_controller.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ydb/core/protos/blobstorage_controller.proto\x12\x12NKikimrBlobStorage\"\xb2\x03\n\x0cTTransaction\x12\x42\n\x0cTxInitScheme\x18\x01 \x01(\x0b\x32,.NKikimrBlobStorage.TTransaction.TInitScheme\x12\x44\n\rTxCreatePDisk\x18\x02 \x01(\x0b\x32-.NKikimrBlobStorage.TTransaction.TCreatePDisk\x12N\n\x12TxCreateVDiskSlots\x18\x03 \x01(\x0b\x32\x32.NKikimrBlobStorage.TTransaction.TCreateVDiskSlots\x12\x44\n\rTxCreateGroup\x18\x04 \x01(\x0b\x32-.NKikimrBlobStorage.TTransaction.TCreateGroup\x1a\x1d\n\x0bTInitScheme\x12\x0e\n\x06Script\x18\x01 \x01(\x0c\x1a\x1e\n\x0cTCreatePDisk\x12\x0e\n\x06Script\x18\x01 \x01(\x0c\x1a#\n\x11TCreateVDiskSlots\x12\x0e\n\x06Script\x18\x01 \x01(\x0c\x1a\x1e\n\x0cTCreateGroup\x12\x0e\n\x06Script\x18\x01 \x01(\x0c\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.blobstorage_controller_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TTRANSACTION._serialized_start=69
  _TTRANSACTION._serialized_end=503
  _TTRANSACTION_TINITSCHEME._serialized_start=373
  _TTRANSACTION_TINITSCHEME._serialized_end=402
  _TTRANSACTION_TCREATEPDISK._serialized_start=404
  _TTRANSACTION_TCREATEPDISK._serialized_end=434
  _TTRANSACTION_TCREATEVDISKSLOTS._serialized_start=436
  _TTRANSACTION_TCREATEVDISKSLOTS._serialized_end=471
  _TTRANSACTION_TCREATEGROUP._serialized_start=473
  _TTRANSACTION_TCREATEGROUP._serialized_end=503
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/serverless_proxy_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import config_pb2 as ydb_dot_core_dot_protos_dot_config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ydb/core/protos/serverless_proxy_config.proto\x12\rNKikimrConfig\x1a\x1cydb/core/protos/config.proto\"\x9c\x02\n\x16TServerlessProxyConfig\x12\x33\n\nHttpConfig\x18\x01 \x01(\x0b\x32\x1f.NKikimrConfig.THttpProxyConfig\x12.\n\nGRpcConfig\x18\x02 \x01(\x0b\x32\x1a.NKikimrConfig.TGRpcConfig\x12\x0e\n\x06\x43\x61\x43\x65rt\x18\x03 \x01(\t\x12\x1f\n\x17\x44\x61tabaseServiceEndpoint\x18\x04 \x01(\t\x12,\n DatabaseListRefreshPeriodSeconds\x18\x05 \x01(\r:\x02\x31\x30\x12\x10\n\x08TestMode\x18\x06 \x01(\x08\x12,\n\tLogConfig\x18\x07 \x01(\x0b\x32\x19.NKikimrConfig.TLogConfigB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.serverless_proxy_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TSERVERLESSPROXYCONFIG._serialized_start=95
  _TSERVERLESSPROXYCONFIG._serialized_end=379
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/profiler.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eydb/core/protos/profiler.proto\x12\x0fNActorsProfiler\"\x1a\n\x08TEvStart\x12\x0e\n\x06\x43ookie\x18\x01 \x01(\x04\".\n\x0eTEvStartResult\x12\x0e\n\x06\x43ookie\x18\x01 \x01(\x04\x12\x0c\n\x04IsOk\x18\x02 \x01(\x08\"\x19\n\x07TEvStop\x12\x0e\n\x06\x43ookie\x18\x01 \x01(\x04\">\n\rTEvStopResult\x12\x0e\n\x06\x43ookie\x18\x01 \x01(\x04\x12\x0f\n\x07Profile\x18\x02 \x01(\t\x12\x0c\n\x04IsOk\x18\x03 \x01(\x08\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.profiler_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TEVSTART._serialized_start=51
  _TEVSTART._serialized_end=77
  _TEVSTARTRESULT._serialized_start=79
  _TEVSTARTRESULT._serialized_end=125
  _TEVSTOP._serialized_start=127
  _TEVSTOP._serialized_end=152
  _TEVSTOPRESULT._serialized_start=154
  _TEVSTOPRESULT._serialized_end=216
# @@protoc_insertion_point(module_scope)
